@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
   based on code from kopete
 
   This library is free software; you can redistribute it and/or modify it
@@ -46,7 +46,7 @@ class EmoticonTextEditSelector : public QWidget
 {
     Q_OBJECT
 public:
-    explicit EmoticonTextEditSelector(QWidget *parent = Q_NULLPTR);
+    explicit EmoticonTextEditSelector(QWidget *parent = nullptr);
     ~EmoticonTextEditSelector();
 
 public Q_SLOTS:
