@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -28,13 +28,21 @@
 #include <QCheckBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QDebug>
 #include <QSpinBox>
 #include <QVBoxLayout>
+#include <QMimeDatabase>
+#include <QDebug>
 
 namespace KPIMTextEdit
 {
 
+static inline QString resolveAlias(const QString& name)
+{
+    QMimeDatabase db;
+    const QString str = db.mimeTypeForName(name).name();
+    return str;
+}
+
 class InsertImageWidgetPrivate
 {
 public:
@@ -47,18 +55,17 @@ public:
         QLabel *lab = new QLabel(i18n("Image Location:"));
         imageUrlRequester = new KUrlRequester;
 
-        const QList<QByteArray> mimetypes = QImageReader::supportedImageFormats();
-        QString filter;
-        Q_FOREACH (const QByteArray &ba, mimetypes) {
-            if (!filter.isEmpty()) {
-                filter += QLatin1Char('\n');
+        QStringList lstMimeTypes;
+        const QList<QByteArray> mimetypes = QImageReader::supportedMimeTypes();
+        lstMimeTypes.reserve(mimetypes.count());
+        for (const QByteArray &ba : mimetypes) {
+            const QString resolvedAlias = resolveAlias(QString::fromUtf8(ba));
+            if (!resolvedAlias.isEmpty()) {
+                lstMimeTypes << resolvedAlias;
             }
-            filter += QStringLiteral("*.%1").arg(QString::fromLatin1(ba));
         }
-        imageUrlRequester->setFilter(filter);
+        imageUrlRequester->setMimeTypeFilters(lstMimeTypes);
         imageUrlRequester->setWindowTitle(i18n("Add Image"));
-        //QT5       imageUrlRequester->fileDialog()->okButton()->setGuiItem(
-        //         KGuiItem( i18n( "&Add" ), QLatin1String( "document-open" ) ) );
         imageUrlRequester->setMode(KFile::File);
         q->connect(imageUrlRequester->lineEdit(), SIGNAL(textChanged(QString)),
                    q, SLOT(_k_slotUrlChanged(QString)));
