@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -31,13 +31,13 @@ class SelectSpecialCharDialogPrivate
 {
 public:
     SelectSpecialCharDialogPrivate(SelectSpecialCharDialog *qq)
-        : mSelectButton(0), q(qq)
+        : mSelectButton(nullptr), q(qq)
     {
         q->setWindowTitle(i18n("Select Special Characters"));
 
         QVBoxLayout *lay = new QVBoxLayout(q);
 
-        mCharSelect = new KCharSelect(q, 0, KCharSelect::CharacterTable | KCharSelect::BlockCombos);
+        mCharSelect = new KCharSelect(q, nullptr, KCharSelect::CharacterTable | KCharSelect::BlockCombos);
         q->connect(mCharSelect, &KCharSelect::charSelected,
                    q, &SelectSpecialCharDialog::charSelected);
         lay->addWidget(mCharSelect);
