@@ -31,7 +31,7 @@ static const int SLIDE_DURATION = 250;
 
 SlideContainer::SlideContainer(QWidget *parent)
     : QFrame(parent),
-      mContent(Q_NULLPTR),
+      mContent(nullptr),
       mSlidingOut(false)
 {
     setFixedHeight(0);
@@ -46,7 +46,7 @@ QWidget *SlideContainer::content() const
 void SlideContainer::setContent(QWidget *content)
 {
     if (mContent) {
-        mContent->setParent(Q_NULLPTR);
+        mContent->setParent(nullptr);
         mContent->removeEventFilter(this);
     }
     mContent = content;
