@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ using namespace KPIMTextEdit;
 class KPIMTextEdit::PlainTextEditFindBarPrivate
 {
 public:
-    PlainTextEditFindBarPrivate(QPlainTextEdit *view)
+    explicit PlainTextEditFindBarPrivate(QPlainTextEdit *view)
         : mView(view)
     {
 
