@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,6 @@
 #include "slidecontainer.h"
 
 #include <QVBoxLayout>
-#include <QShortcut>
 #include <QTextCursor>
 
 using namespace KPIMTextEdit;
@@ -32,10 +31,10 @@ class KPIMTextEdit::PlainTextEditorWidgetPrivate
 {
 public:
     PlainTextEditorWidgetPrivate()
-        : mFindBar(Q_NULLPTR),
-          mEditor(Q_NULLPTR),
-          mTextToSpeechWidget(Q_NULLPTR),
-          mSliderContainer(Q_NULLPTR)
+        : mFindBar(nullptr),
+          mEditor(nullptr),
+          mTextToSpeechWidget(nullptr),
+          mSliderContainer(nullptr)
     {
 
     }
@@ -98,7 +97,7 @@ QString PlainTextEditorWidget::toPlainText() const
 
 void PlainTextEditorWidget::init(PlainTextEditor *customEditor)
 {
-    QVBoxLayout *lay = new QVBoxLayout;
+    QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setMargin(0);
     d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
@@ -123,8 +122,6 @@ void PlainTextEditorWidget::init(PlainTextEditor *customEditor)
     connect(d->mEditor, &PlainTextEditor::findText, this, &PlainTextEditorWidget::slotFind);
 
     connect(d->mEditor, &PlainTextEditor::replaceText, this, &PlainTextEditorWidget::slotReplace);
-
-    setLayout(lay);
 }
 
 void PlainTextEditorWidget::slotHideFindBar()
