@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,6 +18,8 @@
 */
 
 #include "richtexteditor.h"
+#include "kpimtextedit_debug.h"
+#include "helper_p.h"
 #include "texteditor/commonwidget/textmessageindicator.h"
 #include <KLocalizedString>
 #include <KStandardAction>
@@ -48,7 +50,9 @@
 #include <QScrollBar>
 #include <QApplication>
 #include <QClipboard>
-#include <QDebug>
+#include <QDialogButtonBox>
+#include <QPushButton>
+
 
 using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN RichTextEditor::RichTextEditorPrivate
@@ -57,8 +61,8 @@ public:
     RichTextEditorPrivate(RichTextEditor *qq)
         : q(qq),
           textIndicator(new KPIMTextEdit::TextMessageIndicator(q)),
-          richTextDecorator(Q_NULLPTR),
-          speller(Q_NULLPTR),
+          richTextDecorator(nullptr),
+          speller(nullptr),
           webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q)),
           mInitialFontSize(0),
           customPalette(false),
@@ -122,7 +126,7 @@ Sonnet::Highlighter *RichTextEditor::highlighter() const
     if (d->richTextDecorator) {
         return d->richTextDecorator->highlighter();
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -153,7 +157,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         if (!isReadOnly()) {
             QList<QAction *> actionList = popup->actions();
             enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
-            QAction *separatorAction = Q_NULLPTR;
+            QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
             if (idx < actionList.count()) {
                 separatorAction = actionList.at(idx);
@@ -207,16 +211,15 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
                     QActionGroup *languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
-                    QMapIterator<QString, QString> i(d->speller->availableDictionaries());
 
                     QString defaultSpellcheckingLanguage = spellCheckingLanguage();
                     if (defaultSpellcheckingLanguage.isEmpty()) {
                         defaultSpellcheckingLanguage = d->speller->defaultLanguage();
                     }
 
-                    while (i.hasNext()) {
+                    QMapIterator<QString, QString> i(d->speller->availableDictionaries());
+                    while(i.hasNext()) {
                         i.next();
-
                         QAction *languageAction = languagesMenu->addAction(i.key());
                         languageAction->setCheckable(true);
                         languageAction->setChecked(defaultSpellcheckingLanguage == i.value());
@@ -252,7 +255,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         addExtraMenuEntry(popup, pos);
         return popup;
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void RichTextEditor::slotSpeakText()
@@ -432,11 +435,20 @@ void RichTextEditor::checkSpelling(bool force)
         backgroundSpellCheck->changeLanguage(d->spellCheckingLanguage);
     }
     if (!d->ignoreSpellCheckingWords.isEmpty()) {
-        Q_FOREACH (const QString &word, d->ignoreSpellCheckingWords) {
+        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
             backgroundSpellCheck->speller().addToSession(word);
         }
     }
-    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, force ? this : Q_NULLPTR);
+    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, force ? this : nullptr);
+    QDialogButtonBox *buttonBox = spellDialog->findChild<QDialogButtonBox *>();
+    if (buttonBox) {
+        QPushButton *skipButton = new QPushButton(i18n("Skip"));
+        buttonBox->addButton(skipButton, QDialogButtonBox::ActionRole);
+        connect(skipButton, &QPushButton::clicked, spellDialog, &Sonnet::Dialog::close);
+        connect(skipButton, &QPushButton::clicked, this, &RichTextEditor::spellCheckingFinished);
+    } else {
+        qCWarning(KPIMTEXTEDIT_LOG) << " Impossible to find qdialogbuttonbox";
+    }
     backgroundSpellCheck->setParent(spellDialog);
     spellDialog->setAttribute(Qt::WA_DeleteOnClose, true);
     spellDialog->activeAutoCorrect(d->showAutoCorrectionButton);
@@ -535,7 +547,7 @@ void RichTextEditor::addIgnoreWordsToHighLighter()
     }
     if (d->richTextDecorator) {
         Sonnet::Highlighter *_highlighter = d->richTextDecorator->highlighter();
-        Q_FOREACH (const QString &word, d->ignoreSpellCheckingWords) {
+        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
             _highlighter->ignoreWord(word);
         }
     }
@@ -624,7 +636,7 @@ void RichTextEditor::updateHighLighter()
 void RichTextEditor::clearDecorator()
 {
     delete d->richTextDecorator;
-    d->richTextDecorator = Q_NULLPTR;
+    d->richTextDecorator = nullptr;
 }
 
 const QString &RichTextEditor::spellCheckingLanguage() const
