@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,12 +35,12 @@ class KPIMTextEdit::TextToSpeechWidgetPrivate
 public:
     TextToSpeechWidgetPrivate()
         : mNeedToHide(false),
-          mStopButton(Q_NULLPTR),
-          mPlayPauseButton(Q_NULLPTR),
-          mConfigureButton(Q_NULLPTR),
-          mTextToSpeechInterface(Q_NULLPTR),
-          mTextToSpeechActions(Q_NULLPTR),
-          mVolume(Q_NULLPTR)
+          mStopButton(nullptr),
+          mPlayPauseButton(nullptr),
+          mConfigureButton(nullptr),
+          mTextToSpeechInterface(nullptr),
+          mTextToSpeechActions(nullptr),
+          mVolume(nullptr)
     {
 
     }
